==> mozilla-source-0.7.tar.bz2: mozilla/embedding/browser/activex/src/control/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by MozillaControl.rc
//
#define IDS_PROJNAME                    100
#define IDR_MOZILLABROWSER              101
#define IDI_MOZILLABROWSER              201
#define IDC_CHECKMSG                    201
#define IDR_POPUP_PAGE                  202
#define IDC_BUTTON1                     202
#define IDR_POPUP_DOCUMENT              202
#define IDR_POPUP_LINK                  203
#define IDC_BUTTON2                     203
#define IDR_POPUP_CLIPBOARD             204
#define IDC_QUESTION                    204
#define IDR_POPUP_TEXT                  204
#define IDD_CONFIRMCHECK                205
#define IDC_MESSAGE                     205
#define IDD_PROMPT                      206
#define IDR_POPUP_IMAGE                 206
#define IDC_PPAGE_MARKER                206
#define IDD_PROMPTUSERNAMEANDPASSWORD   207
#define IDD_PROMPTPASSWORD              208
#define IDC_TYPE                        208
#define IDD_PROPERTIES                  209
#define IDC_PROTOCOL                    209
#define IDD_PPAGE_LINK                  210
#define IDC_ADDRESS                     210
#define IDS_LOCATEMOZILLA               1000
#define IDS_LOCATEMOZILLATITLE          1001
#define IDS_CANNOTCREATEPREFS           1002
#define ID_BROWSE_BACK                  32768
#define ID_DOCUMENT_BACK                32768
#define ID_BROWSE_FORWARD               32769
#define ID_DOCUMENT_FORWARD             32769
#define ID_FILE_REFRESH                 32772
#define ID_DOCUMENT_REFRESH             32772
#define ID_FILE_PRINT                   32773
#define ID_DOCUMENT_PRINT               32773
#define ID_PAGE_PROPERTIES              32774
#define ID_DOCUMENT_PROPERTIES          32774
#define ID_FILE_VIEWSOURCE              32775
#define ID_DOCUMENT_VIEWSOURCE          32775
#define ID_FILE_OPEN                    32776
#define ID_LINK_OPEN                    32776
#define ID_FILE_OPENINNEWWINDOW         32777
#define ID_LINK_OPENINNEWWINDOW         32777
#define ID_EDIT_COPYSHORTCUT            32778
#define ID_LINK_COPYSHORTCUT            32778
#define ID_LINK_PROPERTIES              32779
#define ID_EDIT_CUT                     32780
#define ID_EDIT_COPY                    32781
#define ID_EDIT_PASTE                   32782
#define ID_EDIT_SELECTALL               32783
#define ID_SELECTIONPOPUP_PRINT         32784
#define ID_DOCUMENT_SELECTALL           32785
#define ID_DOCUMENT_PASTE               32786
#define ID_TEXT_CUT                     32787
#define ID_TEXT_COPY                    32788
#define ID_TEXT_PASTE                   32789
#define ID_TEXT_SELECTALL               32790
#define ID_TEXT_PRINT                   32791

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        211
#define _APS_NEXT_COMMAND_VALUE         32792
#define _APS_NEXT_CONTROL_VALUE         211
#define _APS_NEXT_SYMED_VALUE           102
#endif
#endif

==> mozilla-source-1.3.tar.bz2: mozilla/embedding/browser/activex/src/control/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by MozillaControl.rc
//
#define IDS_PROJNAME                    100
#define IDR_MOZILLABROWSER              101
#define IDI_MOZILLABROWSER              201
#define IDC_CHECKMSG                    201
#define IDR_POPUP_PAGE                  202
#define IDR_POPUP_DOCUMENT              202
#define IDR_POPUP_LINK                  203
#define IDR_POPUP_CLIPBOARD             204
#define IDC_QUESTION                    204
#define IDR_POPUP_TEXT                  204
#define IDD_CONFIRMCHECK                205
#define IDC_MESSAGE                     205
#define IDD_PROMPT                      206
#define IDR_POPUP_IMAGE                 206
#define IDC_PPAGE_MARKER                206
#define IDD_PROMPTUSERNAMEANDPASSWORD   207
#define IDD_PROMPTUSERPASS              207
#define IDD_PROMPTPASSWORD              208
#define IDC_TYPE                        208
#define IDD_PROPERTIES                  209
#define IDC_PROTOCOL                    209
#define IDD_PPAGE_LINK                  210
#define IDC_ADDRESS                     210
#define IDD_CONFIRMEX                   211
#define IDD_HELPERAPP                   212
#define IDC_VALUE                       213
#define IDD_PROGRESS                    213
#define IDC_USERNAME                    214
#define IDC_PASSWORD                    215
#define IDC_CHOOSE                      218
#define IDC_URL                         222
#define IDC_CONTENTTYPE                 223
#define IDC_APPLICATION                 224
#define IDC_SOURCE                      225
#define IDC_DESTINATION                 226
#define IDC_PROGRESS                    227
#define IDC_OPENWITHAPP                 300
#define IDC_SAVETOFILE                  301
#define IDS_LOCATEMOZILLA               1000
#define IDS_LOCATEMOZILLATITLE          1001
#define IDS_CANNOTCREATEPREFS           1002
#define IDS_CONFIRMEX_OK                2000
#define IDS_CONFIRMEX_CANCEL            2001
#define IDS_CONFIRMEX_YES               2002
#define IDS_CONFIRMEX_NO                2003
#define IDS_CONFIRMEX_SAVE              2004
#define IDS_CONFIRMEX_DONTSAVE          2005
#define IDS_CONFIRMEX_REVERT            2006
#define IDC_BUTTON0                     2200
#define IDC_BUTTON1                     2201
#define IDC_BUTTON2                     2202
#define ID_BROWSE_BACK                  32768
#define ID_DOCUMENT_BACK                32768
#define ID_BROWSE_FORWARD               32769
#define ID_DOCUMENT_FORWARD             32769
#define ID_FILE_REFRESH                 32772
#define ID_DOCUMENT_REFRESH             32772
#define ID_FILE_PRINT                   32773
#define ID_DOCUMENT_PRINT               32773
#define ID_PAGE_PROPERTIES              32774
#define ID_DOCUMENT_PROPERTIES          32774
#define ID_FILE_VIEWSOURCE              32775
#define ID_DOCUMENT_VIEWSOURCE          32775
#define ID_FILE_OPEN                    32776
#define ID_LINK_OPEN                    32776
#define ID_FILE_OPENINNEWWINDOW         32777
#define ID_LINK_OPENINNEWWINDOW         32777
#define ID_EDIT_COPYSHORTCUT            32778
#define ID_LINK_COPYSHORTCUT            32778
#define ID_LINK_PROPERTIES              32779
#define ID_EDIT_CUT                     32780
#define ID_EDIT_COPY                    32781
#define ID_EDIT_PASTE                   32782
#define ID_EDIT_SELECTALL               32783
#define ID_SELECTIONPOPUP_PRINT         32784
#define ID_DOCUMENT_SELECTALL           32785
#define ID_DOCUMENT_PASTE               32786
#define ID_TEXT_CUT                     32787
#define ID_TEXT_COPY                    32788
#define ID_TEXT_PASTE                   32789
#define ID_TEXT_SELECTALL               32790
#define ID_TEXT_PRINT                   32791

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        214
#define _APS_NEXT_COMMAND_VALUE         32792
#define _APS_NEXT_CONTROL_VALUE         228
#define _APS_NEXT_SYMED_VALUE           102
#endif
#endif
